@@ -20,13 +20,13 @@
  */
 
 #include <pango/pango-glyph.h>
-#include <pango/pango-engine.h>
+#include <pango/pango-engine-private.h>
 
 /**
  * pango_shape:
  * @text:      the text to process
  * @length:    the length (in bytes) of @text
- * @analysis:  #PangoAnalysis structure from PangoItemize
+ * @analysis:  #PangoAnalysis structure from pango_itemize()
  * @glyphs:    glyph string in which to store results
  *
  * Given a segment of text and the corresponding 
@@ -40,8 +40,12 @@ pango_shape (const gchar      *text,
              PangoAnalysis    *analysis,
              PangoGlyphString *glyphs)
 {
+  int i;
+  int last_cluster = -1;
+  
   if (analysis->shape_engine)
-    analysis->shape_engine->script_shape (analysis->font, text, length, analysis, glyphs);
+    _pango_engine_shape_shape (analysis->shape_engine, analysis->font,
+			       text, length, analysis, glyphs);
   else
     {
       pango_glyph_string_set_size (glyphs, 1);
@@ -55,5 +59,18 @@ pango_shape (const gchar      *text,
       glyphs->log_clusters[0] = 0;
     }
 
+  /* Set glyphs[i].attr.is_cluster_start based on log_clusters[]
+   */
+  for (i = 0; i < glyphs->num_glyphs; i++)
+    {
+      if (glyphs->log_clusters[i] != last_cluster)
+	{
+	  glyphs->glyphs[i].attr.is_cluster_start = TRUE;
+	  last_cluster = glyphs->log_clusters[i];
+	}
+      else
+	glyphs->glyphs[i].attr.is_cluster_start = FALSE;
+    }
+	    
   g_assert (glyphs->num_glyphs > 0);
 }
